@@ -1,46 +1,18 @@
 package Perl::Critic::Policy::Perlsecret;
+# ABSTRACT: Prevent perlsecrets entering your codebase
 
 use 5.006001;
 use strict;
 use warnings;
 
-use base 'Perl::Critic::Policy';
+use parent 'Perl::Critic::Policy';
 
 use Carp;
 use Perl::Critic::Utils;
 
-=head1 NAME
-
-Perl::Critic::Policy::Perlsecret - Prevent Perlsecret operators and constants.
-
-
-=head1 VERSION
-
-Version 0.0.1
-
-=cut
 
 our $VERSION = '0.0.3';
 
-=head1 AFFILIATION
-
-This is a standalone policy not part of a larger PerlCritic Policies group.
-
-
-=head1 DESCRIPTION
-
-Prevents Perlsecrets appearing in your codebase.
-
-=head1 CONFIGURATION
-
-...
-
-=head1 LIMITATIONS
-
-Probably many...
-
-=cut
-
 Readonly::Scalar my $DESCRIPTION => 'Perlsecret risk.';
 Readonly::Scalar my $EXPLANATION => 'Perlsecret detected: %s';
 
@@ -94,65 +66,40 @@ sub violates {
     return;    # No matches return i.e. no violations
 }
 
-=head1 BUGS
+1;
 
-Please report any bugs or feature requests through the web interface at
-L<https://github.com/lancew/Perl-Critic-Policy-Perlsecret/issues>.
-I will be notified, and then you'll automatically be notified of progress on
-your bug as I make changes.
+__END__
 
+=pod
 
-=head1 SUPPORT
+=encoding UTF-8
 
-You can find documentation for this module with the perldoc command.
+=head1 NAME
 
-    perldoc Perl::Critic::Policy::Perlsecret
+Perl::Critic::Policy::Perlsecret - Prevent perlsecrets entering your codebase
 
+=head1 VERSION
 
-You can also look for information at:
+version 0.0.4
 
-=over 4
+=head1 NAME
 
-=item * GitHub (report bugs there)
+Perl::Critic::Policy::Perlsecret - Prevent perlsecrets entering your codebase
 
-L<https://github.com/lancew/Perl-Critic-Policy-Perlsecret/issues>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Perl-Critic-Policy-Perlsecret>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/Perl-Critic-Policy-Perlsecret>
-
-=item * MetaCPAN
-
-L<https://metacpan.org/release/Perl-Critic-Policy-Perlsecret>
-
-=back
+=head1 VERSION
 
+version 0.0.4
 
 =head1 AUTHOR
 
-L<Lance Wicks|https://metacpan.org/author/LANCEW>,
-C<< <lancew at cpan.org> >>.
+Lance Wicks <lancew@cpan.org>
 
+=head1 COPYRIGHT AND LICENSE
 
-=head1 COPYRIGHT & LICENSE
+This software is Copyright (c) 2014 by Lance Wicks.
 
-Copyright 2014 Lance Wicks.
+This is free software, licensed under:
 
-This program is free software: you can redistribute it and/or modify it under
-the terms of the GNU General Public License version 3 as published by the Free
-Software Foundation.
-
-This program is distributed in the hope that it will be useful, but WITHOUT ANY
-WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
-PARTICULAR PURPOSE. See the GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License along with
-this program. If not, see http://www.gnu.org/licenses/
+  The GNU General Public License, Version 3, June 2007
 
 =cut
-
-1;
